@@ -149,7 +149,7 @@ def crontab_add():
 
 @taks(alias='cron-rm')
 def crontab_remove():
-    dj('crontab remove)
+    dj('crontab remove')
 
 
 @task(alias='cron-list')
